==> ruby-vtk_0.1.1.orig.tar.gz: ruby-vtk-0.1.1.orig/IO/IO.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkIOInstantiator(void);
extern SWIGEXPORT(void) Init_vtkBYUReader(void);
extern SWIGEXPORT(void) Init_vtkBase64Utilities(void);
extern SWIGEXPORT(void) Init_vtkDEMReader(void);
extern SWIGEXPORT(void) Init_vtkDataCompressor(void);
extern SWIGEXPORT(void) Init_vtkDataReader(void);
extern SWIGEXPORT(void) Init_vtkDataSetReader(void);
extern SWIGEXPORT(void) Init_vtkGenericEnSightReader(void);
extern SWIGEXPORT(void) Init_vtkImageReader2(void);
extern SWIGEXPORT(void) Init_vtkImageReader2Collection(void);
extern SWIGEXPORT(void) Init_vtkImageReader2Factory(void);
extern SWIGEXPORT(void) Init_vtkImageWriter(void);
extern SWIGEXPORT(void) Init_vtkInputStream(void);
extern SWIGEXPORT(void) Init_vtkJPEGReader(void);
extern SWIGEXPORT(void) Init_vtkJPEGWriter(void);
extern SWIGEXPORT(void) Init_vtkMCubesReader(void);
extern SWIGEXPORT(void) Init_vtkMedicalImageReader2(void);
extern SWIGEXPORT(void) Init_vtkOBJReader(void);
extern SWIGEXPORT(void) Init_vtkOutputStream(void);
extern SWIGEXPORT(void) Init_vtkPLOT3DReader(void);
extern SWIGEXPORT(void) Init_vtkPLY(void);
extern SWIGEXPORT(void) Init_vtkPLYReader(void);
extern SWIGEXPORT(void) Init_vtkPNGReader(void);
extern SWIGEXPORT(void) Init_vtkPNGWriter(void);
extern SWIGEXPORT(void) Init_vtkPNMWriter(void);
extern SWIGEXPORT(void) Init_vtkParticleReader(void);
extern SWIGEXPORT(void) Init_vtkPolyDataReader(void);
extern SWIGEXPORT(void) Init_vtkPostScriptWriter(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridReader(void);
extern SWIGEXPORT(void) Init_vtkSLCReader(void);
extern SWIGEXPORT(void) Init_vtkSTLReader(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsReader(void);
extern SWIGEXPORT(void) Init_vtkTIFFReader(void);
extern SWIGEXPORT(void) Init_vtkTIFFWriter(void);
extern SWIGEXPORT(void) Init_vtkUGFacetReader(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkVolumeReader(void);
extern SWIGEXPORT(void) Init_vtkWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLDataElement(void);
extern SWIGEXPORT(void) Init_vtkXMLParser(void);
extern SWIGEXPORT(void) Init_vtkXMLReader(void);
extern SWIGEXPORT(void) Init_vtkXMLWriter(void);
extern SWIGEXPORT(void) Init_vtkZLibDataCompressor(void);
extern SWIGEXPORT(void) Init_vtkBMPWriter(void);
extern SWIGEXPORT(void) Init_vtkBase64InputStream(void);
extern SWIGEXPORT(void) Init_vtkBase64OutputStream(void);
extern SWIGEXPORT(void) Init_vtkDataObjectReader(void);
extern SWIGEXPORT(void) Init_vtkDataWriter(void);
extern SWIGEXPORT(void) Init_vtkEnSightMasterServerReader(void);
extern SWIGEXPORT(void) Init_vtkEnSightReader(void);
extern SWIGEXPORT(void) Init_vtkGESignaReader(void);
extern SWIGEXPORT(void) Init_vtkImageReader(void);
extern SWIGEXPORT(void) Init_vtkPNMReader(void);
extern SWIGEXPORT(void) Init_vtkPolyDataWriter(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridWriter(void);
extern SWIGEXPORT(void) Init_vtkSTLWriter(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsWriter(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkVolume16Reader(void);
extern SWIGEXPORT(void) Init_vtkXMLDataParser(void);
extern SWIGEXPORT(void) Init_vtkXMLDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLFileReadTester(void);
extern SWIGEXPORT(void) Init_vtkXMLPDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkBMPReader(void);
extern SWIGEXPORT(void) Init_vtkBYUWriter(void);
extern SWIGEXPORT(void) Init_vtkDataObjectWriter(void);
extern SWIGEXPORT(void) Init_vtkDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkEnSight6BinaryReader(void);
extern SWIGEXPORT(void) Init_vtkEnSight6Reader(void);
extern SWIGEXPORT(void) Init_vtkEnSightGoldBinaryReader(void);
extern SWIGEXPORT(void) Init_vtkEnSightGoldReader(void);
extern SWIGEXPORT(void) Init_vtkIVWriter(void);
extern SWIGEXPORT(void) Init_vtkMCubesWriter(void);
extern SWIGEXPORT(void) Init_vtkPLYWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLImageDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLImageDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPImageDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPImageDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPPolyDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPPolyDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPRectilinearGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPRectilinearGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPolyDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPolyDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLRectilinearGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLRectilinearGridWriter(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_IO(void){

  Init_vtkIOInstantiator();
  Init_vtkBYUReader();
  Init_vtkBase64Utilities();
  Init_vtkDEMReader();
  Init_vtkDataCompressor();
  Init_vtkDataReader();
  Init_vtkDataSetReader();
  Init_vtkGenericEnSightReader();
  Init_vtkImageReader2();
  Init_vtkImageReader2Collection();
  Init_vtkImageReader2Factory();
  Init_vtkImageWriter();
  Init_vtkInputStream();
  Init_vtkJPEGReader();
  Init_vtkJPEGWriter();
  Init_vtkMCubesReader();
  Init_vtkMedicalImageReader2();
  Init_vtkOBJReader();
  Init_vtkOutputStream();
  Init_vtkPLOT3DReader();
  Init_vtkPLY();
  Init_vtkPLYReader();
  Init_vtkPNGReader();
  Init_vtkPNGWriter();
  Init_vtkPNMWriter();
  Init_vtkParticleReader();
  Init_vtkPolyDataReader();
  Init_vtkPostScriptWriter();
  Init_vtkRectilinearGridReader();
  Init_vtkSLCReader();
  Init_vtkSTLReader();
  Init_vtkStructuredGridReader();
  Init_vtkStructuredPointsReader();
  Init_vtkTIFFReader();
  Init_vtkTIFFWriter();
  Init_vtkUGFacetReader();
  Init_vtkUnstructuredGridReader();
  Init_vtkVolumeReader();
  Init_vtkWriter();
  Init_vtkXMLDataElement();
  Init_vtkXMLParser();
  Init_vtkXMLReader();
  Init_vtkXMLWriter();
  Init_vtkZLibDataCompressor();
  Init_vtkBMPWriter();
  Init_vtkBase64InputStream();
  Init_vtkBase64OutputStream();
  Init_vtkDataObjectReader();
  Init_vtkDataWriter();
  Init_vtkEnSightMasterServerReader();
  Init_vtkEnSightReader();
  Init_vtkGESignaReader();
  Init_vtkImageReader();
  Init_vtkPNMReader();
  Init_vtkPolyDataWriter();
  Init_vtkRectilinearGridWriter();
  Init_vtkSTLWriter();
  Init_vtkStructuredGridWriter();
  Init_vtkStructuredPointsWriter();
  Init_vtkUnstructuredGridWriter();
  Init_vtkVolume16Reader();
  Init_vtkXMLDataParser();
  Init_vtkXMLDataReader();
  Init_vtkXMLDataSetWriter();
  Init_vtkXMLFileReadTester();
  Init_vtkXMLPDataReader();
  Init_vtkXMLPDataWriter();
  Init_vtkXMLPStructuredDataReader();
  Init_vtkXMLPStructuredDataWriter();
  Init_vtkXMLPStructuredGridReader();
  Init_vtkXMLPStructuredGridWriter();
  Init_vtkXMLPUnstructuredDataReader();
  Init_vtkXMLPUnstructuredDataWriter();
  Init_vtkXMLPUnstructuredGridReader();
  Init_vtkXMLPUnstructuredGridWriter();
  Init_vtkXMLStructuredDataReader();
  Init_vtkXMLStructuredDataWriter();
  Init_vtkXMLStructuredGridReader();
  Init_vtkXMLStructuredGridWriter();
  Init_vtkXMLUnstructuredDataReader();
  Init_vtkXMLUnstructuredDataWriter();
  Init_vtkXMLUnstructuredGridReader();
  Init_vtkXMLUnstructuredGridWriter();
  Init_vtkBMPReader();
  Init_vtkBYUWriter();
  Init_vtkDataObjectWriter();
  Init_vtkDataSetWriter();
  Init_vtkEnSight6BinaryReader();
  Init_vtkEnSight6Reader();
  Init_vtkEnSightGoldBinaryReader();
  Init_vtkEnSightGoldReader();
  Init_vtkIVWriter();
  Init_vtkMCubesWriter();
  Init_vtkPLYWriter();
  Init_vtkXMLImageDataReader();
  Init_vtkXMLImageDataWriter();
  Init_vtkXMLPDataSetWriter();
  Init_vtkXMLPImageDataReader();
  Init_vtkXMLPImageDataWriter();
  Init_vtkXMLPPolyDataReader();
  Init_vtkXMLPPolyDataWriter();
  Init_vtkXMLPRectilinearGridReader();
  Init_vtkXMLPRectilinearGridWriter();
  Init_vtkXMLPolyDataReader();
  Init_vtkXMLPolyDataWriter();
  Init_vtkXMLRectilinearGridReader();
  Init_vtkXMLRectilinearGridWriter();
}

==> ruby-vtk_0.2.0.orig.tar.gz: ruby-vtk-0.2.0.orig/IO/IO.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkIOInstantiator(void);
extern SWIGEXPORT(void) Init_vtkAVSucdReader(void);
extern SWIGEXPORT(void) Init_vtkBYUReader(void);
extern SWIGEXPORT(void) Init_vtkBase64Utilities(void);
extern SWIGEXPORT(void) Init_vtkDEMReader(void);
extern SWIGEXPORT(void) Init_vtkDataCompressor(void);
extern SWIGEXPORT(void) Init_vtkDataReader(void);
extern SWIGEXPORT(void) Init_vtkDataSetReader(void);
extern SWIGEXPORT(void) Init_vtkGenericEnSightReader(void);
extern SWIGEXPORT(void) Init_vtkImageReader2(void);
extern SWIGEXPORT(void) Init_vtkImageReader2Collection(void);
extern SWIGEXPORT(void) Init_vtkImageReader2Factory(void);
extern SWIGEXPORT(void) Init_vtkImageWriter(void);
extern SWIGEXPORT(void) Init_vtkInputStream(void);
extern SWIGEXPORT(void) Init_vtkJPEGReader(void);
extern SWIGEXPORT(void) Init_vtkJPEGWriter(void);
extern SWIGEXPORT(void) Init_vtkMCubesReader(void);
extern SWIGEXPORT(void) Init_vtkMedicalImageReader2(void);
extern SWIGEXPORT(void) Init_vtkMetaImageWriter(void);
extern SWIGEXPORT(void) Init_vtkMoleculeReaderBase(void);
extern SWIGEXPORT(void) Init_vtkOBJReader(void);
extern SWIGEXPORT(void) Init_vtkOutputStream(void);
extern SWIGEXPORT(void) Init_vtkPDBReader(void);
extern SWIGEXPORT(void) Init_vtkPLOT3DReader(void);
extern SWIGEXPORT(void) Init_vtkPLY(void);
extern SWIGEXPORT(void) Init_vtkPLYReader(void);
extern SWIGEXPORT(void) Init_vtkPNGReader(void);
extern SWIGEXPORT(void) Init_vtkPNGWriter(void);
extern SWIGEXPORT(void) Init_vtkPNMWriter(void);
extern SWIGEXPORT(void) Init_vtkParticleReader(void);
extern SWIGEXPORT(void) Init_vtkPolyDataReader(void);
extern SWIGEXPORT(void) Init_vtkPostScriptWriter(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridReader(void);
extern SWIGEXPORT(void) Init_vtkSLCReader(void);
extern SWIGEXPORT(void) Init_vtkSTLReader(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsReader(void);
extern SWIGEXPORT(void) Init_vtkTIFFReader(void);
extern SWIGEXPORT(void) Init_vtkTIFFWriter(void);
extern SWIGEXPORT(void) Init_vtkUGFacetReader(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkVolumeReader(void);
extern SWIGEXPORT(void) Init_vtkWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLDataElement(void);
extern SWIGEXPORT(void) Init_vtkXMLParser(void);
extern SWIGEXPORT(void) Init_vtkXMLReader(void);
extern SWIGEXPORT(void) Init_vtkXMLUtilities(void);
extern SWIGEXPORT(void) Init_vtkXMLWriter(void);
extern SWIGEXPORT(void) Init_vtkXYZMolReader(void);
extern SWIGEXPORT(void) Init_vtkZLibDataCompressor(void);
extern SWIGEXPORT(void) Init_vtkBMPWriter(void);
extern SWIGEXPORT(void) Init_vtkBase64InputStream(void);
extern SWIGEXPORT(void) Init_vtkBase64OutputStream(void);
extern SWIGEXPORT(void) Init_vtkDICOMImageReader(void);
extern SWIGEXPORT(void) Init_vtkDataObjectReader(void);
extern SWIGEXPORT(void) Init_vtkDataWriter(void);
extern SWIGEXPORT(void) Init_vtkEnSightMasterServerReader(void);
extern SWIGEXPORT(void) Init_vtkEnSightReader(void);
extern SWIGEXPORT(void) Init_vtkGESignaReader(void);
extern SWIGEXPORT(void) Init_vtkGaussianCubeReader(void);
extern SWIGEXPORT(void) Init_vtkImageReader(void);
extern SWIGEXPORT(void) Init_vtkMetaImageReader(void);
extern SWIGEXPORT(void) Init_vtkPNMReader(void);
extern SWIGEXPORT(void) Init_vtkPolyDataWriter(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridWriter(void);
extern SWIGEXPORT(void) Init_vtkSTLWriter(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsWriter(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkVolume16Reader(void);
extern SWIGEXPORT(void) Init_vtkXMLDataParser(void);
extern SWIGEXPORT(void) Init_vtkXMLDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLFileReadTester(void);
extern SWIGEXPORT(void) Init_vtkXMLPDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPStructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPUnstructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLStructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLUnstructuredGridWriter(void);
extern SWIGEXPORT(void) Init_vtkBMPReader(void);
extern SWIGEXPORT(void) Init_vtkBYUWriter(void);
extern SWIGEXPORT(void) Init_vtkCGMWriter(void);
extern SWIGEXPORT(void) Init_vtkDataObjectWriter(void);
extern SWIGEXPORT(void) Init_vtkDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkEnSight6BinaryReader(void);
extern SWIGEXPORT(void) Init_vtkEnSight6Reader(void);
extern SWIGEXPORT(void) Init_vtkEnSightGoldBinaryReader(void);
extern SWIGEXPORT(void) Init_vtkEnSightGoldReader(void);
extern SWIGEXPORT(void) Init_vtkIVWriter(void);
extern SWIGEXPORT(void) Init_vtkMCubesWriter(void);
extern SWIGEXPORT(void) Init_vtkPLYWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLImageDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLImageDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPDataSetWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPImageDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPImageDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPPolyDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPPolyDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPRectilinearGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPRectilinearGridWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLPolyDataReader(void);
extern SWIGEXPORT(void) Init_vtkXMLPolyDataWriter(void);
extern SWIGEXPORT(void) Init_vtkXMLRectilinearGridReader(void);
extern SWIGEXPORT(void) Init_vtkXMLRectilinearGridWriter(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_IO(void){

  Init_vtkIOInstantiator();
  Init_vtkAVSucdReader();
  Init_vtkBYUReader();
  Init_vtkBase64Utilities();
  Init_vtkDEMReader();
  Init_vtkDataCompressor();
  Init_vtkDataReader();
  Init_vtkDataSetReader();
  Init_vtkGenericEnSightReader();
  Init_vtkImageReader2();
  Init_vtkImageReader2Collection();
  Init_vtkImageReader2Factory();
  Init_vtkImageWriter();
  Init_vtkInputStream();
  Init_vtkJPEGReader();
  Init_vtkJPEGWriter();
  Init_vtkMCubesReader();
  Init_vtkMedicalImageReader2();
  Init_vtkMetaImageWriter();
  Init_vtkMoleculeReaderBase();
  Init_vtkOBJReader();
  Init_vtkOutputStream();
  Init_vtkPDBReader();
  Init_vtkPLOT3DReader();
  Init_vtkPLY();
  Init_vtkPLYReader();
  Init_vtkPNGReader();
  Init_vtkPNGWriter();
  Init_vtkPNMWriter();
  Init_vtkParticleReader();
  Init_vtkPolyDataReader();
  Init_vtkPostScriptWriter();
  Init_vtkRectilinearGridReader();
  Init_vtkSLCReader();
  Init_vtkSTLReader();
  Init_vtkStructuredGridReader();
  Init_vtkStructuredPointsReader();
  Init_vtkTIFFReader();
  Init_vtkTIFFWriter();
  Init_vtkUGFacetReader();
  Init_vtkUnstructuredGridReader();
  Init_vtkVolumeReader();
  Init_vtkWriter();
  Init_vtkXMLDataElement();
  Init_vtkXMLParser();
  Init_vtkXMLReader();
  Init_vtkXMLUtilities();
  Init_vtkXMLWriter();
  Init_vtkXYZMolReader();
  Init_vtkZLibDataCompressor();
  Init_vtkBMPWriter();
  Init_vtkBase64InputStream();
  Init_vtkBase64OutputStream();
  Init_vtkDICOMImageReader();
  Init_vtkDataObjectReader();
  Init_vtkDataWriter();
  Init_vtkEnSightMasterServerReader();
  Init_vtkEnSightReader();
  Init_vtkGESignaReader();
  Init_vtkGaussianCubeReader();
  Init_vtkImageReader();
  Init_vtkMetaImageReader();
  Init_vtkPNMReader();
  Init_vtkPolyDataWriter();
  Init_vtkRectilinearGridWriter();
  Init_vtkSTLWriter();
  Init_vtkStructuredGridWriter();
  Init_vtkStructuredPointsWriter();
  Init_vtkUnstructuredGridWriter();
  Init_vtkVolume16Reader();
  Init_vtkXMLDataParser();
  Init_vtkXMLDataReader();
  Init_vtkXMLDataSetWriter();
  Init_vtkXMLFileReadTester();
  Init_vtkXMLPDataReader();
  Init_vtkXMLPDataWriter();
  Init_vtkXMLPStructuredDataReader();
  Init_vtkXMLPStructuredDataWriter();
  Init_vtkXMLPStructuredGridReader();
  Init_vtkXMLPStructuredGridWriter();
  Init_vtkXMLPUnstructuredDataReader();
  Init_vtkXMLPUnstructuredDataWriter();
  Init_vtkXMLPUnstructuredGridReader();
  Init_vtkXMLPUnstructuredGridWriter();
  Init_vtkXMLStructuredDataReader();
  Init_vtkXMLStructuredDataWriter();
  Init_vtkXMLStructuredGridReader();
  Init_vtkXMLStructuredGridWriter();
  Init_vtkXMLUnstructuredDataReader();
  Init_vtkXMLUnstructuredDataWriter();
  Init_vtkXMLUnstructuredGridReader();
  Init_vtkXMLUnstructuredGridWriter();
  Init_vtkBMPReader();
  Init_vtkBYUWriter();
  Init_vtkCGMWriter();
  Init_vtkDataObjectWriter();
  Init_vtkDataSetWriter();
  Init_vtkEnSight6BinaryReader();
  Init_vtkEnSight6Reader();
  Init_vtkEnSightGoldBinaryReader();
  Init_vtkEnSightGoldReader();
  Init_vtkIVWriter();
  Init_vtkMCubesWriter();
  Init_vtkPLYWriter();
  Init_vtkXMLImageDataReader();
  Init_vtkXMLImageDataWriter();
  Init_vtkXMLPDataSetWriter();
  Init_vtkXMLPImageDataReader();
  Init_vtkXMLPImageDataWriter();
  Init_vtkXMLPPolyDataReader();
  Init_vtkXMLPPolyDataWriter();
  Init_vtkXMLPRectilinearGridReader();
  Init_vtkXMLPRectilinearGridWriter();
  Init_vtkXMLPolyDataReader();
  Init_vtkXMLPolyDataWriter();
  Init_vtkXMLRectilinearGridReader();
  Init_vtkXMLRectilinearGridWriter();
}
